@@ -1,4 +1,4 @@
-use crate::errors::Error;
+use crate::error::Error;
 
 const MINIMUM_PACKET_SIZE: usize = 20;
 
@@ -16,6 +16,7 @@ impl IpV4Protocol {
     }
 }
 
+#[derive(Debug)]
 pub struct IpV4Packet<'a> {
     pub protocol: IpV4Protocol,
     pub data: &'a [u8],
